/****************************************************************************
** Meta object code from reading C++ file 'qmenuitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../libplasma-6.6.5/src/declarativeimports/plasmaextracomponents/qmenuitem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmenuitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9QMenuItemE_t {};
} // unnamed namespace

template <> constexpr inline auto QMenuItem::qt_create_metaobjectdata<qt_meta_tag_ZN9QMenuItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QMenuItem",
        "QML.Element",
        "auto",
        "MenuItem",
        "clicked",
        "",
        "actionChanged",
        "iconChanged",
        "separatorChanged",
        "sectionChanged",
        "textChanged",
        "toggled",
        "checked",
        "checkableChanged",
        "enabledChanged",
        "visibleChanged",
        "parent",
        "separator",
        "section",
        "text",
        "icon",
        "QVariant",
        "action",
        "QAction*",
        "checkable",
        "enabled",
        "visible"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clicked'
        QtMocHelpers::SignalData<void()>(4, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionChanged'
        QtMocHelpers::SignalData<void()>(6, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void()>(7, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'separatorChanged'
        QtMocHelpers::SignalData<void()>(8, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sectionChanged'
        QtMocHelpers::SignalData<void()>(9, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(10, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toggled'
        QtMocHelpers::SignalData<void(bool)>(11, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'checkableChanged'
        QtMocHelpers::SignalData<void()>(13, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(14, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void()>(15, 5, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'parent'
        QtMocHelpers::PropertyData<QObject*>(16, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'separator'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'section'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'icon'
        QtMocHelpers::PropertyData<QVariant>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'action'
        QtMocHelpers::PropertyData<QAction*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'checkable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'checked'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    1,    3 },
    });
    return QtMocHelpers::metaObjectData<QMenuItem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QMenuItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QMenuItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QMenuItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9QMenuItemE_t>.metaTypes,
    nullptr
} };

void QMenuItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QMenuItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clicked(); break;
        case 1: _t->actionChanged(); break;
        case 2: _t->iconChanged(); break;
        case 3: _t->separatorChanged(); break;
        case 4: _t->sectionChanged(); break;
        case 5: _t->textChanged(); break;
        case 6: _t->toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->checkableChanged(); break;
        case 8: _t->enabledChanged(); break;
        case 9: _t->visibleChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QMenuItem::*)()>(_a, &QMenuItem::clicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuItem::*)()>(_a, &QMenuItem::actionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuItem::*)()>(_a, &QMenuItem::iconChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuItem::*)()>(_a, &QMenuItem::separatorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuItem::*)()>(_a, &QMenuItem::sectionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuItem::*)()>(_a, &QMenuItem::textChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuItem::*)(bool )>(_a, &QMenuItem::toggled, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuItem::*)()>(_a, &QMenuItem::checkableChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuItem::*)()>(_a, &QMenuItem::enabledChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuItem::*)()>(_a, &QMenuItem::visibleChanged, 9))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->parent(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->separator(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->section(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 4: *reinterpret_cast<QVariant*>(_v) = _t->icon(); break;
        case 5: *reinterpret_cast<QAction**>(_v) = _t->action(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->checkable(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->checked(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isVisible(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setParent(*reinterpret_cast<QObject**>(_v)); break;
        case 1: _t->setSeparator(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setSection(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setIcon(*reinterpret_cast<QVariant*>(_v)); break;
        case 5: _t->setAction(*reinterpret_cast<QAction**>(_v)); break;
        case 6: _t->setCheckable(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setChecked(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setVisible(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QMenuItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QMenuItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QMenuItemE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QMenuItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void QMenuItem::clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QMenuItem::actionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QMenuItem::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QMenuItem::separatorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QMenuItem::sectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QMenuItem::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QMenuItem::toggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void QMenuItem::checkableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QMenuItem::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QMenuItem::visibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
