/****************************************************************************
** Meta object code from reading C++ file 'corona.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.6.5/src/plasma/corona.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'corona.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Plasma6CoronaE_t {};
} // unnamed namespace

template <> constexpr inline auto Plasma::Corona::qt_create_metaobjectdata<qt_meta_tag_ZN6Plasma6CoronaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plasma::Corona",
        "containmentAdded",
        "",
        "Plasma::Containment*",
        "containment",
        "containmentCreated",
        "screenOwnerChanged",
        "isScreen",
        "configSynced",
        "availableScreenRegionChanged",
        "id",
        "availableScreenRectChanged",
        "screenGeometryChanged",
        "immutabilityChanged",
        "Plasma::Types::ImmutabilityType",
        "immutability",
        "screenRemoved",
        "screenAdded",
        "editModeChanged",
        "edit",
        "kPackageChanged",
        "KPackage::Package",
        "package",
        "startupCompleted",
        "loadLayout",
        "config",
        "saveLayout",
        "setImmutability",
        "Types::ImmutabilityType",
        "immutable",
        "requestConfigSync",
        "requireConfigSync",
        "containmentDestroyed",
        "syncConfig",
        "toggleImmutability",
        "containmentReady",
        "action",
        "QAction*",
        "name",
        "isStartupCompleted",
        "editMode",
        "kPackage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'containmentAdded'
        QtMocHelpers::SignalData<void(Plasma::Containment *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'containmentCreated'
        QtMocHelpers::SignalData<void(Plasma::Containment *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'screenOwnerChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'configSynced'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableScreenRegionChanged'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'availableScreenRectChanged'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'screenGeometryChanged'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'immutabilityChanged'
        QtMocHelpers::SignalData<void(Plasma::Types::ImmutabilityType)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'screenRemoved'
        QtMocHelpers::SignalData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'screenAdded'
        QtMocHelpers::SignalData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'editModeChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Signal 'kPackageChanged'
        QtMocHelpers::SignalData<void(const KPackage::Package &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'startupCompleted'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadLayout'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'loadLayout'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'saveLayout'
        QtMocHelpers::SlotData<void(const QString &) const>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'saveLayout'
        QtMocHelpers::SlotData<void() const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setImmutability'
        QtMocHelpers::SlotData<void(const Types::ImmutabilityType)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'requestConfigSync'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requireConfigSync'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'containmentDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 2 },
        }}),
        // Slot 'syncConfig'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleImmutability'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'containmentReady'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Method 'action'
        QtMocHelpers::MethodData<QAction *(const QString &) const>(36, 2, QMC::AccessPublic, 0x80000000 | 37, {{
            { QMetaType::QString, 38 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isStartupCompleted'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
        // property 'editMode'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'kPackage'
        QtMocHelpers::PropertyData<KPackage::Package>(41, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Corona, qt_meta_tag_ZN6Plasma6CoronaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plasma::Corona::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma6CoronaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma6CoronaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Plasma6CoronaE_t>.metaTypes,
    nullptr
} };

void Plasma::Corona::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Corona *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->containmentAdded((*reinterpret_cast<std::add_pointer_t<Plasma::Containment*>>(_a[1]))); break;
        case 1: _t->containmentCreated((*reinterpret_cast<std::add_pointer_t<Plasma::Containment*>>(_a[1]))); break;
        case 2: _t->screenOwnerChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->configSynced(); break;
        case 4: _t->availableScreenRegionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->availableScreenRectChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->screenGeometryChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->immutabilityChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Types::ImmutabilityType>>(_a[1]))); break;
        case 8: _t->screenRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->screenAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->editModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->kPackageChanged((*reinterpret_cast<std::add_pointer_t<KPackage::Package>>(_a[1]))); break;
        case 12: _t->startupCompleted(); break;
        case 13: _t->loadLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->loadLayout(); break;
        case 15: _t->saveLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->saveLayout(); break;
        case 17: _t->setImmutability((*reinterpret_cast<std::add_pointer_t<Types::ImmutabilityType>>(_a[1]))); break;
        case 18: _t->requestConfigSync(); break;
        case 19: _t->requireConfigSync(); break;
        case 20: _t->d->containmentDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 21: _t->d->syncConfig(); break;
        case 22: _t->d->toggleImmutability(); break;
        case 23: _t->d->containmentReady((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: { QAction* _r = _t->action((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAction**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Containment* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Containment* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Corona::*)(Plasma::Containment * )>(_a, &Corona::containmentAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)(Plasma::Containment * )>(_a, &Corona::containmentCreated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)(int )>(_a, &Corona::screenOwnerChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)()>(_a, &Corona::configSynced, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)(int )>(_a, &Corona::availableScreenRegionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)(int )>(_a, &Corona::availableScreenRectChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)(int )>(_a, &Corona::screenGeometryChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)(Plasma::Types::ImmutabilityType )>(_a, &Corona::immutabilityChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)(int )>(_a, &Corona::screenRemoved, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)(int )>(_a, &Corona::screenAdded, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)(bool )>(_a, &Corona::editModeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)(const KPackage::Package & )>(_a, &Corona::kPackageChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Corona::*)()>(_a, &Corona::startupCompleted, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isStartupCompleted(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isEditMode(); break;
        case 2: *reinterpret_cast<KPackage::Package*>(_v) = _t->kPackage(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setEditMode(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Plasma::Corona::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma::Corona::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma6CoronaE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Plasma::Corona::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Plasma::Corona::containmentAdded(Plasma::Containment * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Plasma::Corona::containmentCreated(Plasma::Containment * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Plasma::Corona::screenOwnerChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Plasma::Corona::configSynced()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Plasma::Corona::availableScreenRegionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Plasma::Corona::availableScreenRectChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Plasma::Corona::screenGeometryChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Plasma::Corona::immutabilityChanged(Plasma::Types::ImmutabilityType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Plasma::Corona::screenRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Plasma::Corona::screenAdded(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Plasma::Corona::editModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Plasma::Corona::kPackageChanged(const KPackage::Package & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Plasma::Corona::startupCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
