/*
    SPDX-FileCopyrightText: 2007-2009 Aaron Seigo <aseigo@kde.org>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "packages_p.h"

K_PLUGIN_CLASS_WITH_JSON(Plasma::GenericPackage, "plasma_generic_packagestructure.json")

#include "plasma_generic_packagestructure.moc"
