// This file was generated by qtwaylandscanner
// source file is blur.xml

#include "qwayland-blur.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
    bindOpCode, interface, version, name, interface->name, version, nullptr);
}

    org_kde_kwin_blur_manager::org_kde_kwin_blur_manager(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    org_kde_kwin_blur_manager::org_kde_kwin_blur_manager(struct ::org_kde_kwin_blur_manager *obj)
        : m_org_kde_kwin_blur_manager(obj)
    {
    }

    org_kde_kwin_blur_manager::org_kde_kwin_blur_manager()
        : m_org_kde_kwin_blur_manager(nullptr)
    {
    }

    org_kde_kwin_blur_manager::~org_kde_kwin_blur_manager()
    {
    }

    void org_kde_kwin_blur_manager::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_org_kde_kwin_blur_manager = static_cast<struct ::org_kde_kwin_blur_manager *>(wlRegistryBind(registry, id, &org_kde_kwin_blur_manager_interface, version));
    }

    void org_kde_kwin_blur_manager::init(struct ::org_kde_kwin_blur_manager *obj)
    {
        m_org_kde_kwin_blur_manager = obj;
    }

    org_kde_kwin_blur_manager *org_kde_kwin_blur_manager::fromObject(struct ::org_kde_kwin_blur_manager *object)
    {
        return static_cast<org_kde_kwin_blur_manager *>(org_kde_kwin_blur_manager_get_user_data(object));
    }

    bool org_kde_kwin_blur_manager::isInitialized() const
    {
        return m_org_kde_kwin_blur_manager != nullptr;
    }

    uint32_t org_kde_kwin_blur_manager::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_org_kde_kwin_blur_manager));
    }

    const struct wl_interface *org_kde_kwin_blur_manager::interface()
    {
        return &::org_kde_kwin_blur_manager_interface;
    }

    struct ::org_kde_kwin_blur *org_kde_kwin_blur_manager::create(struct ::wl_surface *surface)
    {
        struct ::org_kde_kwin_blur * id = ::org_kde_kwin_blur_manager_create(
            m_org_kde_kwin_blur_manager,
            surface);
        return id;
    }

    void org_kde_kwin_blur_manager::unset(struct ::wl_surface *surface)
    {
        ::org_kde_kwin_blur_manager_unset(
            m_org_kde_kwin_blur_manager,
            surface);
    }

    org_kde_kwin_blur::org_kde_kwin_blur(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    org_kde_kwin_blur::org_kde_kwin_blur(struct ::org_kde_kwin_blur *obj)
        : m_org_kde_kwin_blur(obj)
    {
    }

    org_kde_kwin_blur::org_kde_kwin_blur()
        : m_org_kde_kwin_blur(nullptr)
    {
    }

    org_kde_kwin_blur::~org_kde_kwin_blur()
    {
    }

    void org_kde_kwin_blur::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_org_kde_kwin_blur = static_cast<struct ::org_kde_kwin_blur *>(wlRegistryBind(registry, id, &org_kde_kwin_blur_interface, version));
    }

    void org_kde_kwin_blur::init(struct ::org_kde_kwin_blur *obj)
    {
        m_org_kde_kwin_blur = obj;
    }

    org_kde_kwin_blur *org_kde_kwin_blur::fromObject(struct ::org_kde_kwin_blur *object)
    {
        return static_cast<org_kde_kwin_blur *>(org_kde_kwin_blur_get_user_data(object));
    }

    bool org_kde_kwin_blur::isInitialized() const
    {
        return m_org_kde_kwin_blur != nullptr;
    }

    uint32_t org_kde_kwin_blur::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_org_kde_kwin_blur));
    }

    const struct wl_interface *org_kde_kwin_blur::interface()
    {
        return &::org_kde_kwin_blur_interface;
    }

    void org_kde_kwin_blur::commit()
    {
        ::org_kde_kwin_blur_commit(
            m_org_kde_kwin_blur);
    }

    void org_kde_kwin_blur::set_region(struct ::wl_region *region)
    {
        ::org_kde_kwin_blur_set_region(
            m_org_kde_kwin_blur,
            region);
    }

    void org_kde_kwin_blur::release()
    {
        ::org_kde_kwin_blur_release(
            m_org_kde_kwin_blur);
        m_org_kde_kwin_blur = nullptr;
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
