/****************************************************************************
** Meta object code from reading C++ file 'dialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.6.5/src/plasmaquick/dialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PlasmaQuick6DialogE_t {};
} // unnamed namespace

template <> constexpr inline auto PlasmaQuick::Dialog::qt_create_metaobjectdata<qt_meta_tag_ZN11PlasmaQuick6DialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlasmaQuick::Dialog",
        "DefaultProperty",
        "mainItem",
        "mainItemChanged",
        "",
        "locationChanged",
        "visualParentChanged",
        "typeChanged",
        "hideOnWindowDeactivateChanged",
        "outputOnlyChanged",
        "flagsChanged",
        "floatingChanged",
        "backgroundHintsChanged",
        "visibleChangedProxy",
        "appletInterfaceChanged",
        "windowDeactivated",
        "updateTheme",
        "updateVisibility",
        "visible",
        "updateMinimumWidth",
        "updateMinimumHeight",
        "updateMaximumWidth",
        "updateMaximumHeight",
        "updateLayoutParameters",
        "slotMainItemSizeChanged",
        "QQuickItem*",
        "visualParent",
        "margins",
        "inset",
        "location",
        "Plasma::Types::Location",
        "type",
        "WindowType",
        "hideOnWindowDeactivate",
        "outputOnly",
        "flags",
        "Qt::WindowFlags",
        "backgroundHints",
        "BackgroundHints",
        "floating",
        "appletInterface",
        "Normal",
        "Dock",
        "DialogWindow",
        "PopupMenu",
        "Tooltip",
        "Notification",
        "OnScreenDisplay",
        "CriticalNotification",
        "AppletPopup",
        "NoBackground",
        "StandardBackground",
        "SolidBackground"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mainItemChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'locationChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visualParentChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hideOnWindowDeactivateChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputOnlyChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'flagsChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'floatingChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundHintsChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleChangedProxy'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appletInterfaceChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowDeactivated'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateTheme'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateVisibility'
        QtMocHelpers::SlotData<void(bool)>(17, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'updateMinimumWidth'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMinimumHeight'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMaximumWidth'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMaximumHeight'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateLayoutParameters'
        QtMocHelpers::SlotData<void()>(23, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMainItemSizeChanged'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mainItem'
        QtMocHelpers::PropertyData<QQuickItem*>(2, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'visualParent'
        QtMocHelpers::PropertyData<QQuickItem*>(26, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'margins'
        QtMocHelpers::PropertyData<QObject*>(27, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inset'
        QtMocHelpers::PropertyData<QObject*>(28, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'location'
        QtMocHelpers::PropertyData<Plasma::Types::Location>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'type'
        QtMocHelpers::PropertyData<enum WindowType>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'hideOnWindowDeactivate'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'outputOnly'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'flags'
        QtMocHelpers::PropertyData<Qt::WindowFlags>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 6),
        // property 'backgroundHints'
        QtMocHelpers::PropertyData<enum BackgroundHints>(37, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'floating'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'appletInterface'
        QtMocHelpers::PropertyData<QQuickItem*>(40, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'WindowType'
        QtMocHelpers::EnumData<enum WindowType>(32, 32, QMC::EnumFlags{}).add({
            {   41, WindowType::Normal },
            {   42, WindowType::Dock },
            {   43, WindowType::DialogWindow },
            {   44, WindowType::PopupMenu },
            {   45, WindowType::Tooltip },
            {   46, WindowType::Notification },
            {   47, WindowType::OnScreenDisplay },
            {   48, WindowType::CriticalNotification },
            {   49, WindowType::AppletPopup },
        }),
        // enum 'BackgroundHints'
        QtMocHelpers::EnumData<enum BackgroundHints>(38, 38, QMC::EnumFlags{}).add({
            {   50, BackgroundHints::NoBackground },
            {   51, BackgroundHints::StandardBackground },
            {   52, BackgroundHints::SolidBackground },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Dialog, qt_meta_tag_ZN11PlasmaQuick6DialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN11PlasmaQuick6DialogE[] = {
    QMetaObject::SuperData::link<Plasma::Types::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject PlasmaQuick::Dialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick6DialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick6DialogE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN11PlasmaQuick6DialogE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PlasmaQuick6DialogE_t>.metaTypes,
    nullptr
} };

void PlasmaQuick::Dialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Dialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mainItemChanged(); break;
        case 1: _t->locationChanged(); break;
        case 2: _t->visualParentChanged(); break;
        case 3: _t->typeChanged(); break;
        case 4: _t->hideOnWindowDeactivateChanged(); break;
        case 5: _t->outputOnlyChanged(); break;
        case 6: _t->flagsChanged(); break;
        case 7: _t->floatingChanged(); break;
        case 8: _t->backgroundHintsChanged(); break;
        case 9: _t->visibleChangedProxy(); break;
        case 10: _t->appletInterfaceChanged(); break;
        case 11: _t->windowDeactivated(); break;
        case 12: _t->d->updateTheme(); break;
        case 13: _t->d->updateVisibility((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->d->updateMinimumWidth(); break;
        case 15: _t->d->updateMinimumHeight(); break;
        case 16: _t->d->updateMaximumWidth(); break;
        case 17: _t->d->updateMaximumHeight(); break;
        case 18: _t->d->updateLayoutParameters(); break;
        case 19: _t->d->slotMainItemSizeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::mainItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::locationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::visualParentChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::typeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::hideOnWindowDeactivateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::outputOnlyChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::flagsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::floatingChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::backgroundHintsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::visibleChangedProxy, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::appletInterfaceChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dialog::*)()>(_a, &Dialog::windowDeactivated, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 12:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->mainItem(); break;
        case 1: *reinterpret_cast<QQuickItem**>(_v) = _t->visualParent(); break;
        case 2: *reinterpret_cast<QObject**>(_v) = _t->margins(); break;
        case 3: *reinterpret_cast<QObject**>(_v) = _t->inset(); break;
        case 4: *reinterpret_cast<Plasma::Types::Location*>(_v) = _t->location(); break;
        case 5: *reinterpret_cast<enum WindowType*>(_v) = _t->type(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hideOnWindowDeactivate(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputOnly(); break;
        case 8: *reinterpret_cast<Qt::WindowFlags*>(_v) = _t->flags(); break;
        case 9: *reinterpret_cast<enum BackgroundHints*>(_v) = _t->backgroundHints(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isVisible(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->floating(); break;
        case 12: *reinterpret_cast<QQuickItem**>(_v) = _t->appletInterface(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMainItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 1: _t->setVisualParent(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 4: _t->setLocation(*reinterpret_cast<Plasma::Types::Location*>(_v)); break;
        case 5: _t->setType(*reinterpret_cast<enum WindowType*>(_v)); break;
        case 6: _t->setHideOnWindowDeactivate(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setOutputOnly(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setFramelessFlags(*reinterpret_cast<Qt::WindowFlags*>(_v)); break;
        case 9: _t->setBackgroundHints(*reinterpret_cast<enum BackgroundHints*>(_v)); break;
        case 10: _t->setVisible(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setFloating(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setAppletInterface(*reinterpret_cast<QQuickItem**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PlasmaQuick::Dialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaQuick::Dialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick6DialogE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QQuickWindow::qt_metacast(_clname);
}

int PlasmaQuick::Dialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void PlasmaQuick::Dialog::mainItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PlasmaQuick::Dialog::locationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlasmaQuick::Dialog::visualParentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PlasmaQuick::Dialog::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PlasmaQuick::Dialog::hideOnWindowDeactivateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PlasmaQuick::Dialog::outputOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PlasmaQuick::Dialog::flagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PlasmaQuick::Dialog::floatingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PlasmaQuick::Dialog::backgroundHintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PlasmaQuick::Dialog::visibleChangedProxy()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PlasmaQuick::Dialog::appletInterfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void PlasmaQuick::Dialog::windowDeactivated()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
