/****************************************************************************
** Meta object code from reading C++ file 'appletquickitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.6.5/src/plasmaquick/appletquickitem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appletquickitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PlasmaQuick15AppletQuickItemE_t {};
} // unnamed namespace

template <> constexpr inline auto PlasmaQuick::AppletQuickItem::qt_create_metaobjectdata<qt_meta_tag_ZN11PlasmaQuick15AppletQuickItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlasmaQuick::AppletQuickItem",
        "switchWidthChanged",
        "",
        "width",
        "switchHeightChanged",
        "height",
        "expandedChanged",
        "expanded",
        "activationTogglesExpandedChanged",
        "activationTogglesExpanded",
        "hideOnWindowDeactivateChanged",
        "hide",
        "compactRepresentationChanged",
        "QQmlComponent*",
        "compactRepresentation",
        "fullRepresentationChanged",
        "fullRepresentation",
        "preferredRepresentationChanged",
        "preferredRepresentation",
        "compactRepresentationItemChanged",
        "compactRepresentationItem",
        "fullRepresentationItemChanged",
        "fullRepresentationItem",
        "preloadFullRepresentationChanged",
        "preload",
        "expandedOnDragHoverChanged",
        "expandedOnDragHover",
        "badgeTextChanged",
        "text",
        "minimumWidthChanged",
        "minimumHeightChanged",
        "preferredWidthChanged",
        "preferredHeightChanged",
        "maximumWidthChanged",
        "maximumHeightChanged",
        "fillWidthChanged",
        "fillHeightChanged",
        "switchWidth",
        "switchHeight",
        "QQuickItem*",
        "preloadFullRepresentation",
        "hideOnWindowDeactivate",
        "plasmoid",
        "badgeText"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'switchWidthChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'switchHeightChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'expandedChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'activationTogglesExpandedChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'hideOnWindowDeactivateChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'compactRepresentationChanged'
        QtMocHelpers::SignalData<void(QQmlComponent *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'fullRepresentationChanged'
        QtMocHelpers::SignalData<void(QQmlComponent *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 16 },
        }}),
        // Signal 'preferredRepresentationChanged'
        QtMocHelpers::SignalData<void(QQmlComponent *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 18 },
        }}),
        // Signal 'compactRepresentationItemChanged'
        QtMocHelpers::SignalData<void(QObject *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 20 },
        }}),
        // Signal 'fullRepresentationItemChanged'
        QtMocHelpers::SignalData<void(QObject *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 22 },
        }}),
        // Signal 'preloadFullRepresentationChanged'
        QtMocHelpers::SignalData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'expandedOnDragHoverChanged'
        QtMocHelpers::SignalData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Signal 'badgeTextChanged'
        QtMocHelpers::SignalData<void(QString)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'minimumWidthChanged'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'minimumHeightChanged'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'preferredWidthChanged'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'preferredHeightChanged'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'maximumWidthChanged'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'maximumHeightChanged'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fillWidthChanged'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fillHeightChanged'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'switchWidth'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'switchHeight'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'compactRepresentation'
        QtMocHelpers::PropertyData<QQmlComponent*>(14, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'compactRepresentationItem'
        QtMocHelpers::PropertyData<QQuickItem*>(20, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'fullRepresentation'
        QtMocHelpers::PropertyData<QQmlComponent*>(16, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'fullRepresentationItem'
        QtMocHelpers::PropertyData<QQuickItem*>(22, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'preloadFullRepresentation'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'preferredRepresentation'
        QtMocHelpers::PropertyData<QQmlComponent*>(18, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'expanded'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'activationTogglesExpanded'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'hideOnWindowDeactivate'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'expandedOnDragHover'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'plasmoid'
        QtMocHelpers::PropertyData<QObject*>(42, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'badgeText'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AppletQuickItem, qt_meta_tag_ZN11PlasmaQuick15AppletQuickItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlasmaQuick::AppletQuickItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick15AppletQuickItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick15AppletQuickItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PlasmaQuick15AppletQuickItemE_t>.metaTypes,
    nullptr
} };

void PlasmaQuick::AppletQuickItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppletQuickItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->switchWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->switchHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->expandedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->activationTogglesExpandedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->hideOnWindowDeactivateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->compactRepresentationChanged((*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[1]))); break;
        case 6: _t->fullRepresentationChanged((*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[1]))); break;
        case 7: _t->preferredRepresentationChanged((*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[1]))); break;
        case 8: _t->compactRepresentationItemChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 9: _t->fullRepresentationItemChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 10: _t->preloadFullRepresentationChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->expandedOnDragHoverChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->badgeTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->d->minimumWidthChanged(); break;
        case 14: _t->d->minimumHeightChanged(); break;
        case 15: _t->d->preferredWidthChanged(); break;
        case 16: _t->d->preferredHeightChanged(); break;
        case 17: _t->d->maximumWidthChanged(); break;
        case 18: _t->d->maximumHeightChanged(); break;
        case 19: _t->d->fillWidthChanged(); break;
        case 20: _t->d->fillHeightChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(int )>(_a, &AppletQuickItem::switchWidthChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(int )>(_a, &AppletQuickItem::switchHeightChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(bool )>(_a, &AppletQuickItem::expandedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(bool )>(_a, &AppletQuickItem::activationTogglesExpandedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(bool )>(_a, &AppletQuickItem::hideOnWindowDeactivateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(QQmlComponent * )>(_a, &AppletQuickItem::compactRepresentationChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(QQmlComponent * )>(_a, &AppletQuickItem::fullRepresentationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(QQmlComponent * )>(_a, &AppletQuickItem::preferredRepresentationChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(QObject * )>(_a, &AppletQuickItem::compactRepresentationItemChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(QObject * )>(_a, &AppletQuickItem::fullRepresentationItemChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(bool )>(_a, &AppletQuickItem::preloadFullRepresentationChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(bool )>(_a, &AppletQuickItem::expandedOnDragHoverChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletQuickItem::*)(QString )>(_a, &AppletQuickItem::badgeTextChanged, 12))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
        case 4:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        case 5:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->switchWidth(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->switchHeight(); break;
        case 2: *reinterpret_cast<QQmlComponent**>(_v) = _t->compactRepresentation(); break;
        case 3: *reinterpret_cast<QQuickItem**>(_v) = _t->compactRepresentationItem(); break;
        case 4: *reinterpret_cast<QQmlComponent**>(_v) = _t->fullRepresentation(); break;
        case 5: *reinterpret_cast<QQuickItem**>(_v) = _t->fullRepresentationItem(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->preloadFullRepresentation(); break;
        case 7: *reinterpret_cast<QQmlComponent**>(_v) = _t->preferredRepresentation(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isExpanded(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isActivationTogglesExpanded(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->hideOnWindowDeactivate(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->expandedOnDragHover(); break;
        case 12: *reinterpret_cast<QObject**>(_v) = _t->applet(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->badgeText(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSwitchWidth(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setSwitchHeight(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setCompactRepresentation(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 4: _t->setFullRepresentation(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 6: _t->setPreloadFullRepresentation(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setPreferredRepresentation(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 8: _t->setExpanded(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setActivationTogglesExpanded(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setHideOnWindowDeactivate(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setExpandedOnDragHover(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setBadgeText(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PlasmaQuick::AppletQuickItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaQuick::AppletQuickItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick15AppletQuickItemE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int PlasmaQuick::AppletQuickItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void PlasmaQuick::AppletQuickItem::switchWidthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PlasmaQuick::AppletQuickItem::switchHeightChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PlasmaQuick::AppletQuickItem::expandedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PlasmaQuick::AppletQuickItem::activationTogglesExpandedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PlasmaQuick::AppletQuickItem::hideOnWindowDeactivateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PlasmaQuick::AppletQuickItem::compactRepresentationChanged(QQmlComponent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void PlasmaQuick::AppletQuickItem::fullRepresentationChanged(QQmlComponent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void PlasmaQuick::AppletQuickItem::preferredRepresentationChanged(QQmlComponent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void PlasmaQuick::AppletQuickItem::compactRepresentationItemChanged(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void PlasmaQuick::AppletQuickItem::fullRepresentationItemChanged(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void PlasmaQuick::AppletQuickItem::preloadFullRepresentationChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void PlasmaQuick::AppletQuickItem::expandedOnDragHoverChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void PlasmaQuick::AppletQuickItem::badgeTextChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}
QT_WARNING_POP
