// This file was generated by qtwaylandscanner
// source file is blur.xml

#ifndef QT_WAYLAND_BLUR
#define QT_WAYLAND_BLUR

#include "wayland-blur-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  org_kde_kwin_blur_manager
    {
    public:
        org_kde_kwin_blur_manager(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_kwin_blur_manager(struct ::org_kde_kwin_blur_manager *object);
        org_kde_kwin_blur_manager();

        virtual ~org_kde_kwin_blur_manager();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_kwin_blur_manager *object);

        struct ::org_kde_kwin_blur_manager *object() { return m_org_kde_kwin_blur_manager; }
        const struct ::org_kde_kwin_blur_manager *object() const { return m_org_kde_kwin_blur_manager; }
        static org_kde_kwin_blur_manager *fromObject(struct ::org_kde_kwin_blur_manager *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        struct ::org_kde_kwin_blur *create(struct ::wl_surface *surface);
        void unset(struct ::wl_surface *surface);

    private:
        struct ::org_kde_kwin_blur_manager *m_org_kde_kwin_blur_manager;
    };

    class  org_kde_kwin_blur
    {
    public:
        org_kde_kwin_blur(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_kwin_blur(struct ::org_kde_kwin_blur *object);
        org_kde_kwin_blur();

        virtual ~org_kde_kwin_blur();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_kwin_blur *object);

        struct ::org_kde_kwin_blur *object() { return m_org_kde_kwin_blur; }
        const struct ::org_kde_kwin_blur *object() const { return m_org_kde_kwin_blur; }
        static org_kde_kwin_blur *fromObject(struct ::org_kde_kwin_blur *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void commit();
        void set_region(struct ::wl_region *region);
        void release();

    private:
        struct ::org_kde_kwin_blur *m_org_kde_kwin_blur;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
