// This file was generated by qtwaylandscanner
// source file is plasma-shell.xml

#ifndef QT_WAYLAND_PLASMA_SHELL
#define QT_WAYLAND_PLASMA_SHELL

#include "wayland-plasma-shell-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  org_kde_plasma_shell
    {
    public:
        org_kde_plasma_shell(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_plasma_shell(struct ::org_kde_plasma_shell *object);
        org_kde_plasma_shell();

        virtual ~org_kde_plasma_shell();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_plasma_shell *object);

        struct ::org_kde_plasma_shell *object() { return m_org_kde_plasma_shell; }
        const struct ::org_kde_plasma_shell *object() const { return m_org_kde_plasma_shell; }
        static org_kde_plasma_shell *fromObject(struct ::org_kde_plasma_shell *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        struct ::org_kde_plasma_surface *get_surface(struct ::wl_surface *surface);

    private:
        struct ::org_kde_plasma_shell *m_org_kde_plasma_shell;
    };

    class  org_kde_plasma_surface
    {
    public:
        org_kde_plasma_surface(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_plasma_surface(struct ::org_kde_plasma_surface *object);
        org_kde_plasma_surface();

        virtual ~org_kde_plasma_surface();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_plasma_surface *object);

        struct ::org_kde_plasma_surface *object() { return m_org_kde_plasma_surface; }
        const struct ::org_kde_plasma_surface *object() const { return m_org_kde_plasma_surface; }
        static org_kde_plasma_surface *fromObject(struct ::org_kde_plasma_surface *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum role {
            role_normal = 0,
            role_desktop = 1,
            role_panel = 2,
            role_onscreendisplay = 3,
            role_notification = 4,
            role_tooltip = 5,
            role_criticalnotification = 6,
            role_appletpopup = 7,
        };

        enum panel_behavior {
            panel_behavior_always_visible = 1,
            panel_behavior_auto_hide = 2,
            panel_behavior_windows_can_cover = 3,
            panel_behavior_windows_go_below = 4,
        };

        enum error {
            error_panel_not_auto_hide = 0, // Request panel_auto_hide performed on a surface which does not correspond to an auto-hide panel.
        };

        void destroy();
        void set_output(struct ::wl_output *output);
        void set_position(int32_t x, int32_t y);
        void set_role(uint32_t role);
        void set_panel_behavior(uint32_t flag);
        void set_skip_taskbar(uint32_t skip);
        void panel_auto_hide_hide();
        void panel_auto_hide_show();
        void set_panel_takes_focus(uint32_t takes_focus);
        void set_skip_switcher(uint32_t skip);
        void open_under_cursor();

    protected:
        virtual void org_kde_plasma_surface_auto_hidden_panel_hidden();
        virtual void org_kde_plasma_surface_auto_hidden_panel_shown();

    private:
        void init_listener();
        static const struct org_kde_plasma_surface_listener m_org_kde_plasma_surface_listener;
        static void handle_auto_hidden_panel_hidden(
            void *data,
            struct ::org_kde_plasma_surface *object);
        static void handle_auto_hidden_panel_shown(
            void *data,
            struct ::org_kde_plasma_surface *object);
        struct ::org_kde_plasma_surface *m_org_kde_plasma_surface;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
