/****************************************************************************
** Meta object code from reading C++ file 'plasmoiditem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.6.5/src/plasmaquick/plasmoid/plasmoiditem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plasmoiditem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12PlasmoidItemE_t {};
} // unnamed namespace

template <> constexpr inline auto PlasmoidItem::qt_create_metaobjectdata<qt_meta_tag_ZN12PlasmoidItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlasmoidItem",
        "externalData",
        "",
        "mimetype",
        "QVariant",
        "data",
        "contextualActionsAboutToShow",
        "toolTipMainTextChanged",
        "toolTipSubTextChanged",
        "toolTipTextFormatChanged",
        "toolTipItemChanged",
        "screenChanged",
        "screenGeometryChanged",
        "hideOnWindowDeactivateChanged",
        "availableScreenRegionChanged",
        "availableScreenRectChanged",
        "contextualActionsChanged",
        "prepareContextualActions",
        "toolTipMainText",
        "toolTipSubText",
        "toolTipTextFormat",
        "toolTipItem",
        "QQuickItem*",
        "screen",
        "screenGeometry",
        "QRect",
        "hideOnWindowDeactivate",
        "availableScreenRect",
        "availableScreenRegion",
        "QVariantList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'externalData'
        QtMocHelpers::SignalData<void(const QString &, const QVariant &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'contextualActionsAboutToShow'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toolTipMainTextChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toolTipSubTextChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toolTipTextFormatChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toolTipItemChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenGeometryChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hideOnWindowDeactivateChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableScreenRegionChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableScreenRectChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contextualActionsChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'prepareContextualActions'
        QtMocHelpers::MethodData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'toolTipMainText'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'toolTipSubText'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'toolTipTextFormat'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'toolTipItem'
        QtMocHelpers::PropertyData<QQuickItem*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'screen'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags, 6),
        // property 'screenGeometry'
        QtMocHelpers::PropertyData<QRect>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'hideOnWindowDeactivate'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'availableScreenRect'
        QtMocHelpers::PropertyData<QRect>(27, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'availableScreenRegion'
        QtMocHelpers::PropertyData<QVariantList>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlasmoidItem, qt_meta_tag_ZN12PlasmoidItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlasmoidItem::staticMetaObject = { {
    QMetaObject::SuperData::link<PlasmaQuick::AppletQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PlasmoidItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PlasmoidItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12PlasmoidItemE_t>.metaTypes,
    nullptr
} };

void PlasmoidItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlasmoidItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->externalData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 1: _t->contextualActionsAboutToShow(); break;
        case 2: _t->toolTipMainTextChanged(); break;
        case 3: _t->toolTipSubTextChanged(); break;
        case 4: _t->toolTipTextFormatChanged(); break;
        case 5: _t->toolTipItemChanged(); break;
        case 6: _t->screenChanged(); break;
        case 7: _t->screenGeometryChanged(); break;
        case 8: _t->hideOnWindowDeactivateChanged(); break;
        case 9: _t->availableScreenRegionChanged(); break;
        case 10: _t->availableScreenRectChanged(); break;
        case 11: _t->contextualActionsChanged(); break;
        case 12: _t->prepareContextualActions(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)(const QString & , const QVariant & )>(_a, &PlasmoidItem::externalData, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)()>(_a, &PlasmoidItem::contextualActionsAboutToShow, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)()>(_a, &PlasmoidItem::toolTipMainTextChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)()>(_a, &PlasmoidItem::toolTipSubTextChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)()>(_a, &PlasmoidItem::toolTipTextFormatChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)()>(_a, &PlasmoidItem::toolTipItemChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)()>(_a, &PlasmoidItem::screenChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)()>(_a, &PlasmoidItem::screenGeometryChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)()>(_a, &PlasmoidItem::hideOnWindowDeactivateChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)()>(_a, &PlasmoidItem::availableScreenRegionChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)()>(_a, &PlasmoidItem::availableScreenRectChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmoidItem::*)()>(_a, &PlasmoidItem::contextualActionsChanged, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->toolTipMainText(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->toolTipSubText(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->toolTipTextFormat(); break;
        case 3: *reinterpret_cast<QQuickItem**>(_v) = _t->toolTipItem(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->screen(); break;
        case 5: *reinterpret_cast<QRect*>(_v) = _t->screenGeometry(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hideOnWindowDeactivate(); break;
        case 7: *reinterpret_cast<QRect*>(_v) = _t->availableScreenRect(); break;
        case 8: *reinterpret_cast<QVariantList*>(_v) = _t->availableScreenRegion(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setToolTipMainText(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setToolTipSubText(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setToolTipTextFormat(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setToolTipItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 6: _t->setHideOnWindowDeactivate(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PlasmoidItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmoidItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PlasmoidItemE_t>.strings))
        return static_cast<void*>(this);
    return PlasmaQuick::AppletQuickItem::qt_metacast(_clname);
}

int PlasmoidItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlasmaQuick::AppletQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void PlasmoidItem::externalData(const QString & _t1, const QVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void PlasmoidItem::contextualActionsAboutToShow()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlasmoidItem::toolTipMainTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PlasmoidItem::toolTipSubTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PlasmoidItem::toolTipTextFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PlasmoidItem::toolTipItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PlasmoidItem::screenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PlasmoidItem::screenGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PlasmoidItem::hideOnWindowDeactivateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PlasmoidItem::availableScreenRegionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PlasmoidItem::availableScreenRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void PlasmoidItem::contextualActionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
