/****************************************************************************
** Meta object code from reading C++ file 'popupplasmawindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.6.5/src/plasmaquick/popupplasmawindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'popupplasmawindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PlasmaQuick17PopupPlasmaWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto PlasmaQuick::PopupPlasmaWindow::qt_create_metaobjectdata<qt_meta_tag_ZN11PlasmaQuick17PopupPlasmaWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlasmaQuick::PopupPlasmaWindow",
        "visualParentChanged",
        "",
        "popupDirectionChanged",
        "effectivePopupDirectionChanged",
        "floatingChanged",
        "animatedChanged",
        "removeBorderStrategyChanged",
        "marginChanged",
        "nearbyBordersChanged",
        "queuePositionUpdate",
        "updateVisualParentWindow",
        "visualParent",
        "QQuickItem*",
        "popupDirection",
        "Qt::Edge",
        "effectivePopupDirection",
        "floating",
        "animated",
        "removeBorderStrategy",
        "RemoveBorders",
        "margin",
        "RemoveBorder",
        "Never",
        "AtScreenEdges",
        "AtPanelEdges"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'visualParentChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'popupDirectionChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'effectivePopupDirectionChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'floatingChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'animatedChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'removeBorderStrategyChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'marginChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nearbyBordersChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'queuePositionUpdate'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateVisualParentWindow'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'visualParent'
        QtMocHelpers::PropertyData<QQuickItem*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'popupDirection'
        QtMocHelpers::PropertyData<Qt::Edge>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'effectivePopupDirection'
        QtMocHelpers::PropertyData<Qt::Edge>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'floating'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'animated'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'removeBorderStrategy'
        QtMocHelpers::PropertyData<RemoveBorders>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'margin'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'RemoveBorders'
        QtMocHelpers::EnumData<RemoveBorders>(20, 22, QMC::EnumIsFlag).add({
            {   23, RemoveBorder::Never },
            {   24, RemoveBorder::AtScreenEdges },
            {   25, RemoveBorder::AtPanelEdges },
        }),
    };
    return QtMocHelpers::metaObjectData<PopupPlasmaWindow, qt_meta_tag_ZN11PlasmaQuick17PopupPlasmaWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlasmaQuick::PopupPlasmaWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<PlasmaWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick17PopupPlasmaWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick17PopupPlasmaWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PlasmaQuick17PopupPlasmaWindowE_t>.metaTypes,
    nullptr
} };

void PlasmaQuick::PopupPlasmaWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PopupPlasmaWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->visualParentChanged(); break;
        case 1: _t->popupDirectionChanged(); break;
        case 2: _t->effectivePopupDirectionChanged(); break;
        case 3: _t->floatingChanged(); break;
        case 4: _t->animatedChanged(); break;
        case 5: _t->removeBorderStrategyChanged(); break;
        case 6: _t->marginChanged(); break;
        case 7: _t->nearbyBordersChanged(); break;
        case 8: _t->queuePositionUpdate(); break;
        case 9: _t->d->updateVisualParentWindow(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PopupPlasmaWindow::*)()>(_a, &PopupPlasmaWindow::visualParentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PopupPlasmaWindow::*)()>(_a, &PopupPlasmaWindow::popupDirectionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PopupPlasmaWindow::*)()>(_a, &PopupPlasmaWindow::effectivePopupDirectionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PopupPlasmaWindow::*)()>(_a, &PopupPlasmaWindow::floatingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PopupPlasmaWindow::*)()>(_a, &PopupPlasmaWindow::animatedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PopupPlasmaWindow::*)()>(_a, &PopupPlasmaWindow::removeBorderStrategyChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PopupPlasmaWindow::*)()>(_a, &PopupPlasmaWindow::marginChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PopupPlasmaWindow::*)()>(_a, &PopupPlasmaWindow::nearbyBordersChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->visualParent(); break;
        case 1: *reinterpret_cast<Qt::Edge*>(_v) = _t->popupDirection(); break;
        case 2: *reinterpret_cast<Qt::Edge*>(_v) = _t->effectivePopupDirection(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->floating(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->animated(); break;
        case 5: QtMocHelpers::assignFlags<RemoveBorders>(_v, _t->removeBorderStrategy()); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->margin(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVisualParent(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 1: _t->setPopupDirection(*reinterpret_cast<Qt::Edge*>(_v)); break;
        case 3: _t->setFloating(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setAnimated(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setRemoveBorderStrategy(*reinterpret_cast<RemoveBorders*>(_v)); break;
        case 6: _t->setMargin(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PlasmaQuick::PopupPlasmaWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaQuick::PopupPlasmaWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick17PopupPlasmaWindowE_t>.strings))
        return static_cast<void*>(this);
    return PlasmaWindow::qt_metacast(_clname);
}

int PlasmaQuick::PopupPlasmaWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlasmaWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void PlasmaQuick::PopupPlasmaWindow::visualParentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PlasmaQuick::PopupPlasmaWindow::popupDirectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlasmaQuick::PopupPlasmaWindow::effectivePopupDirectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PlasmaQuick::PopupPlasmaWindow::floatingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PlasmaQuick::PopupPlasmaWindow::animatedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PlasmaQuick::PopupPlasmaWindow::removeBorderStrategyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PlasmaQuick::PopupPlasmaWindow::marginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PlasmaQuick::PopupPlasmaWindow::nearbyBordersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
