/****************************************************************************
** Meta object code from reading C++ file 'tooltiparea.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../libplasma-6.6.5/src/declarativeimports/core/tooltiparea.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tooltiparea.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ToolTipAreaE_t {};
} // unnamed namespace

template <> constexpr inline auto ToolTipArea::qt_create_metaobjectdata<qt_meta_tag_ZN11ToolTipAreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ToolTipArea",
        "QML.Element",
        "auto",
        "mainItemChanged",
        "",
        "mainTextChanged",
        "subTextChanged",
        "textFormatChanged",
        "iconChanged",
        "imageChanged",
        "containsMouseChanged",
        "locationChanged",
        "activeChanged",
        "interactiveChanged",
        "aboutToShow",
        "toolTipVisibleChanged",
        "toolTipVisible",
        "showToolTip",
        "hideToolTip",
        "hideImmediately",
        "settingsChanged",
        "KConfigGroup",
        "group",
        "QByteArrayList",
        "names",
        "mainItem",
        "QQuickItem*",
        "mainText",
        "subText",
        "textFormat",
        "icon",
        "QVariant",
        "containsMouse",
        "location",
        "Plasma::Types::Location",
        "image",
        "active",
        "interactive",
        "timeout"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mainItemChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mainTextChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subTextChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textFormatChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'containsMouseChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'locationChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interactiveChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToShow'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toolTipVisibleChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'showToolTip'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hideToolTip'
        QtMocHelpers::SlotData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hideImmediately'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'settingsChanged'
        QtMocHelpers::SlotData<void(const KConfigGroup &, const QByteArrayList &)>(20, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { 0x80000000 | 23, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mainItem'
        QtMocHelpers::PropertyData<QQuickItem*>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'mainText'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'subText'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'textFormat'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'icon'
        QtMocHelpers::PropertyData<QVariant>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'containsMouse'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'location'
        QtMocHelpers::PropertyData<Plasma::Types::Location>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'image'
        QtMocHelpers::PropertyData<QVariant>(35, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'interactive'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'timeout'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ToolTipArea, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN11ToolTipAreaE[] = {
    QMetaObject::SuperData::link<Plasma::Types::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject ToolTipArea::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ToolTipAreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ToolTipAreaE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN11ToolTipAreaE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ToolTipAreaE_t>.metaTypes,
    nullptr
} };

void ToolTipArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ToolTipArea *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mainItemChanged(); break;
        case 1: _t->mainTextChanged(); break;
        case 2: _t->subTextChanged(); break;
        case 3: _t->textFormatChanged(); break;
        case 4: _t->iconChanged(); break;
        case 5: _t->imageChanged(); break;
        case 6: _t->containsMouseChanged(); break;
        case 7: _t->locationChanged(); break;
        case 8: _t->activeChanged(); break;
        case 9: _t->interactiveChanged(); break;
        case 10: _t->aboutToShow(); break;
        case 11: _t->toolTipVisibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->showToolTip(); break;
        case 13: _t->hideToolTip(); break;
        case 14: _t->hideImmediately(); break;
        case 15: _t->settingsChanged((*reinterpret_cast<std::add_pointer_t<KConfigGroup>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArrayList>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)()>(_a, &ToolTipArea::mainItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)()>(_a, &ToolTipArea::mainTextChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)()>(_a, &ToolTipArea::subTextChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)()>(_a, &ToolTipArea::textFormatChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)()>(_a, &ToolTipArea::iconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)()>(_a, &ToolTipArea::imageChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)()>(_a, &ToolTipArea::containsMouseChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)()>(_a, &ToolTipArea::locationChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)()>(_a, &ToolTipArea::activeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)()>(_a, &ToolTipArea::interactiveChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)()>(_a, &ToolTipArea::aboutToShow, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolTipArea::*)(bool )>(_a, &ToolTipArea::toolTipVisibleChanged, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->mainItem(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->mainText(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->subText(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->textFormat(); break;
        case 4: *reinterpret_cast<QVariant*>(_v) = _t->icon(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->containsMouse(); break;
        case 6: *reinterpret_cast<Plasma::Types::Location*>(_v) = _t->location(); break;
        case 7: *reinterpret_cast<QVariant*>(_v) = _t->image(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->m_active; break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->m_interactive; break;
        case 10: *reinterpret_cast<int*>(_v) = _t->m_timeout; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMainItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 1: _t->setMainText(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setSubText(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setTextFormat(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setIcon(*reinterpret_cast<QVariant*>(_v)); break;
        case 6: _t->setLocation(*reinterpret_cast<Plasma::Types::Location*>(_v)); break;
        case 7: _t->setImage(*reinterpret_cast<QVariant*>(_v)); break;
        case 8: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setInteractive(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setTimeout(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ToolTipArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ToolTipArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ToolTipAreaE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int ToolTipArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void ToolTipArea::mainItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ToolTipArea::mainTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ToolTipArea::subTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ToolTipArea::textFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ToolTipArea::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ToolTipArea::imageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ToolTipArea::containsMouseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ToolTipArea::locationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ToolTipArea::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ToolTipArea::interactiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ToolTipArea::aboutToShow()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ToolTipArea::toolTipVisibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
