// This file was generated by qtwaylandscanner
// source file is plasma-shell.xml

#include "qwayland-plasma-shell.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
    bindOpCode, interface, version, name, interface->name, version, nullptr);
}

    org_kde_plasma_shell::org_kde_plasma_shell(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    org_kde_plasma_shell::org_kde_plasma_shell(struct ::org_kde_plasma_shell *obj)
        : m_org_kde_plasma_shell(obj)
    {
    }

    org_kde_plasma_shell::org_kde_plasma_shell()
        : m_org_kde_plasma_shell(nullptr)
    {
    }

    org_kde_plasma_shell::~org_kde_plasma_shell()
    {
    }

    void org_kde_plasma_shell::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_org_kde_plasma_shell = static_cast<struct ::org_kde_plasma_shell *>(wlRegistryBind(registry, id, &org_kde_plasma_shell_interface, version));
    }

    void org_kde_plasma_shell::init(struct ::org_kde_plasma_shell *obj)
    {
        m_org_kde_plasma_shell = obj;
    }

    org_kde_plasma_shell *org_kde_plasma_shell::fromObject(struct ::org_kde_plasma_shell *object)
    {
        return static_cast<org_kde_plasma_shell *>(org_kde_plasma_shell_get_user_data(object));
    }

    bool org_kde_plasma_shell::isInitialized() const
    {
        return m_org_kde_plasma_shell != nullptr;
    }

    uint32_t org_kde_plasma_shell::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_org_kde_plasma_shell));
    }

    const struct wl_interface *org_kde_plasma_shell::interface()
    {
        return &::org_kde_plasma_shell_interface;
    }

    struct ::org_kde_plasma_surface *org_kde_plasma_shell::get_surface(struct ::wl_surface *surface)
    {
        struct ::org_kde_plasma_surface * id = ::org_kde_plasma_shell_get_surface(
            m_org_kde_plasma_shell,
            surface);
        return id;
    }

    org_kde_plasma_surface::org_kde_plasma_surface(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    org_kde_plasma_surface::org_kde_plasma_surface(struct ::org_kde_plasma_surface *obj)
        : m_org_kde_plasma_surface(obj)
    {
        init_listener();
    }

    org_kde_plasma_surface::org_kde_plasma_surface()
        : m_org_kde_plasma_surface(nullptr)
    {
    }

    org_kde_plasma_surface::~org_kde_plasma_surface()
    {
    }

    void org_kde_plasma_surface::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_org_kde_plasma_surface = static_cast<struct ::org_kde_plasma_surface *>(wlRegistryBind(registry, id, &org_kde_plasma_surface_interface, version));
        init_listener();
    }

    void org_kde_plasma_surface::init(struct ::org_kde_plasma_surface *obj)
    {
        m_org_kde_plasma_surface = obj;
        init_listener();
    }

    org_kde_plasma_surface *org_kde_plasma_surface::fromObject(struct ::org_kde_plasma_surface *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_org_kde_plasma_surface_listener)
            return nullptr;
        return static_cast<org_kde_plasma_surface *>(org_kde_plasma_surface_get_user_data(object));
    }

    bool org_kde_plasma_surface::isInitialized() const
    {
        return m_org_kde_plasma_surface != nullptr;
    }

    uint32_t org_kde_plasma_surface::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_org_kde_plasma_surface));
    }

    const struct wl_interface *org_kde_plasma_surface::interface()
    {
        return &::org_kde_plasma_surface_interface;
    }

    void org_kde_plasma_surface::destroy()
    {
        ::org_kde_plasma_surface_destroy(
            m_org_kde_plasma_surface);
        m_org_kde_plasma_surface = nullptr;
    }

    void org_kde_plasma_surface::set_output(struct ::wl_output *output)
    {
        ::org_kde_plasma_surface_set_output(
            m_org_kde_plasma_surface,
            output);
    }

    void org_kde_plasma_surface::set_position(int32_t x, int32_t y)
    {
        ::org_kde_plasma_surface_set_position(
            m_org_kde_plasma_surface,
            x,
            y);
    }

    void org_kde_plasma_surface::set_role(uint32_t role)
    {
        ::org_kde_plasma_surface_set_role(
            m_org_kde_plasma_surface,
            role);
    }

    void org_kde_plasma_surface::set_panel_behavior(uint32_t flag)
    {
        ::org_kde_plasma_surface_set_panel_behavior(
            m_org_kde_plasma_surface,
            flag);
    }

    void org_kde_plasma_surface::set_skip_taskbar(uint32_t skip)
    {
        ::org_kde_plasma_surface_set_skip_taskbar(
            m_org_kde_plasma_surface,
            skip);
    }

    void org_kde_plasma_surface::panel_auto_hide_hide()
    {
        ::org_kde_plasma_surface_panel_auto_hide_hide(
            m_org_kde_plasma_surface);
    }

    void org_kde_plasma_surface::panel_auto_hide_show()
    {
        ::org_kde_plasma_surface_panel_auto_hide_show(
            m_org_kde_plasma_surface);
    }

    void org_kde_plasma_surface::set_panel_takes_focus(uint32_t takes_focus)
    {
        ::org_kde_plasma_surface_set_panel_takes_focus(
            m_org_kde_plasma_surface,
            takes_focus);
    }

    void org_kde_plasma_surface::set_skip_switcher(uint32_t skip)
    {
        ::org_kde_plasma_surface_set_skip_switcher(
            m_org_kde_plasma_surface,
            skip);
    }

    void org_kde_plasma_surface::open_under_cursor()
    {
        ::org_kde_plasma_surface_open_under_cursor(
            m_org_kde_plasma_surface);
    }

    void org_kde_plasma_surface::org_kde_plasma_surface_auto_hidden_panel_hidden()
    {
    }

    void org_kde_plasma_surface::handle_auto_hidden_panel_hidden(
        void *data,
        struct ::org_kde_plasma_surface *object)
    {
        Q_UNUSED(object);
        static_cast<org_kde_plasma_surface *>(data)->org_kde_plasma_surface_auto_hidden_panel_hidden();
    }

    void org_kde_plasma_surface::org_kde_plasma_surface_auto_hidden_panel_shown()
    {
    }

    void org_kde_plasma_surface::handle_auto_hidden_panel_shown(
        void *data,
        struct ::org_kde_plasma_surface *object)
    {
        Q_UNUSED(object);
        static_cast<org_kde_plasma_surface *>(data)->org_kde_plasma_surface_auto_hidden_panel_shown();
    }

    const struct org_kde_plasma_surface_listener org_kde_plasma_surface::m_org_kde_plasma_surface_listener = {
        org_kde_plasma_surface::handle_auto_hidden_panel_hidden,
        org_kde_plasma_surface::handle_auto_hidden_panel_shown,
    };

    void org_kde_plasma_surface::init_listener()
    {
        org_kde_plasma_surface_add_listener(m_org_kde_plasma_surface, &m_org_kde_plasma_surface_listener, this);
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
