#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_plasma_components_AbstractButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_BusyIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Button_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_CheckBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_CheckDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_CheckIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_ComboBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Container_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Control_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Dial_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Dialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_DialogButtonBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Drawer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Frame_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_GroupBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_ItemDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Label_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Menu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_MenuItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_MenuSeparator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Page_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_PageIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Pane_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Popup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_ProgressBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_RadioButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_RadioDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_RadioIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_RangeSlider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_RoundButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_ScrollBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_ScrollView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Slider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_SpinBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_StackView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_SwipeView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_Switch_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_SwitchDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_SwitchIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_TabBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_TabButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_TextArea_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_TextField_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_ToolBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_ToolButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_ToolTip_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_mobiletextselection_MobileCursor_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_mobiletextselection_MobileTextActionsToolBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_mobiletextselection_MobileTextActionsToolBarImpl_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_private_ButtonBackground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_private_ButtonContent_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_private_ButtonFocus_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_private_ButtonHover_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_private_ButtonShadow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_private_DefaultListItemBackground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_private_FlatButtonBackground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_private_IconLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_private_RaisedButtonBackground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_private_RoundShadow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_plasma_components_private_TextFieldFocus_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/AbstractButton.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_AbstractButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/BusyIndicator.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_BusyIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Button.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Button_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/CheckBox.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_CheckBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/CheckDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_CheckDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/CheckIndicator.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_CheckIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/ComboBox.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_ComboBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Container.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Container_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Control.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Control_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Dial.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Dial_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Dialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Dialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/DialogButtonBox.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_DialogButtonBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Drawer.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Drawer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Frame.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Frame_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/GroupBox.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_GroupBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/ItemDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_ItemDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Label.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Label_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Menu.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Menu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/MenuItem.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_MenuItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/MenuSeparator.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_MenuSeparator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Page.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Page_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/PageIndicator.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_PageIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Pane.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Pane_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Popup.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Popup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/ProgressBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_ProgressBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/RadioButton.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_RadioButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/RadioDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_RadioDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/RadioIndicator.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_RadioIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/RangeSlider.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_RangeSlider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/RoundButton.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_RoundButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/ScrollBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_ScrollBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/ScrollView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_ScrollView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Slider.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Slider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/SpinBox.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_SpinBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/StackView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_StackView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/SwipeView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_SwipeView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/Switch.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_Switch_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/SwitchDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_SwitchDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/SwitchIndicator.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_SwitchIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/TabBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_TabBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/TabButton.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_TabButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/TextArea.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_TextArea_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/TextField.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_TextField_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/ToolBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_ToolBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/ToolButton.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_ToolButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/ToolTip.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_ToolTip_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/mobiletextselection/MobileCursor.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_mobiletextselection_MobileCursor_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/mobiletextselection/MobileTextActionsToolBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_mobiletextselection_MobileTextActionsToolBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/mobiletextselection/MobileTextActionsToolBarImpl.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_mobiletextselection_MobileTextActionsToolBarImpl_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/private/ButtonBackground.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_private_ButtonBackground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/private/ButtonContent.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_private_ButtonContent_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/private/ButtonFocus.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_private_ButtonFocus_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/private/ButtonHover.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_private_ButtonHover_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/private/ButtonShadow.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_private_ButtonShadow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/private/DefaultListItemBackground.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_private_DefaultListItemBackground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/private/FlatButtonBackground.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_private_FlatButtonBackground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/private/IconLabel.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_private_IconLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/private/RaisedButtonBackground.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_private_RaisedButtonBackground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/private/RoundShadow.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_private_RoundShadow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/plasma/components/private/TextFieldFocus.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_plasma_components_private_TextFieldFocus_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_org_kde_plasmacomponents3)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_org_kde_plasmacomponents3))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_org_kde_plasmacomponents3)() {
    return 1;
}
