/****************************************************************************
** Meta object code from reading C++ file 'plasmawindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.6.5/src/plasmaquick/plasmawindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plasmawindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PlasmaQuick12PlasmaWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto PlasmaQuick::PlasmaWindow::qt_create_metaobjectdata<qt_meta_tag_ZN11PlasmaQuick12PlasmaWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlasmaQuick::PlasmaWindow",
        "mainItemChanged",
        "",
        "bordersChanged",
        "backgroundHintsChanged",
        "paddingChanged",
        "mainItem",
        "QQuickItem*",
        "backgroundHints",
        "BackgroundHints",
        "borders",
        "Qt::Edges",
        "topPadding",
        "bottomPadding",
        "leftPadding",
        "rightPadding",
        "StandardBackground",
        "SolidBackground"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mainItemChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bordersChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundHintsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paddingChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mainItem'
        QtMocHelpers::PropertyData<QQuickItem*>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'backgroundHints'
        QtMocHelpers::PropertyData<enum BackgroundHints>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'borders'
        QtMocHelpers::PropertyData<Qt::Edges>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'topPadding'
        QtMocHelpers::PropertyData<qreal>(12, QMetaType::QReal, QMC::DefaultPropertyFlags, 3),
        // property 'bottomPadding'
        QtMocHelpers::PropertyData<qreal>(13, QMetaType::QReal, QMC::DefaultPropertyFlags, 3),
        // property 'leftPadding'
        QtMocHelpers::PropertyData<qreal>(14, QMetaType::QReal, QMC::DefaultPropertyFlags, 3),
        // property 'rightPadding'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'BackgroundHints'
        QtMocHelpers::EnumData<enum BackgroundHints>(9, 9, QMC::EnumFlags{}).add({
            {   16, BackgroundHints::StandardBackground },
            {   17, BackgroundHints::SolidBackground },
        }),
    };
    return QtMocHelpers::metaObjectData<PlasmaWindow, qt_meta_tag_ZN11PlasmaQuick12PlasmaWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlasmaQuick::PlasmaWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick12PlasmaWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick12PlasmaWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PlasmaQuick12PlasmaWindowE_t>.metaTypes,
    nullptr
} };

void PlasmaQuick::PlasmaWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlasmaWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mainItemChanged(); break;
        case 1: _t->bordersChanged(); break;
        case 2: _t->backgroundHintsChanged(); break;
        case 3: _t->paddingChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::mainItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::bordersChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::backgroundHintsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::paddingChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->mainItem(); break;
        case 1: *reinterpret_cast<enum BackgroundHints*>(_v) = _t->backgroundHints(); break;
        case 2: *reinterpret_cast<Qt::Edges*>(_v) = _t->borders(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->topPadding(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->bottomPadding(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->leftPadding(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->rightPadding(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMainItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 1: _t->setBackgroundHints(*reinterpret_cast<enum BackgroundHints*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PlasmaQuick::PlasmaWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaQuick::PlasmaWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick12PlasmaWindowE_t>.strings))
        return static_cast<void*>(this);
    return QQuickWindow::qt_metacast(_clname);
}

int PlasmaQuick::PlasmaWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void PlasmaQuick::PlasmaWindow::mainItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PlasmaQuick::PlasmaWindow::bordersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlasmaQuick::PlasmaWindow::backgroundHintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PlasmaQuick::PlasmaWindow::paddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
